@@ -179,6 +179,13 @@ def test_read_and_write(test_images):
             assert diff.mean() < 2.5
 
 
+def test_v3_read(test_images):
+    # this should trigger the plugin default
+    # and read all frames by default
+    frames = iio3.imread(test_images / "cockatoo.mp4")
+    assert frames.shape == (280, 720, 1280, 3)
+
+
 def test_write_not_contiguous(test_images):
 
     fname1 = test_images / "cockatoo.mp4"
@@ -608,7 +615,7 @@ def show_in_visvis(test_images):
     # reader = iio.read(test_images / "cockatoo.mp4", "ffmpeg")
     reader = iio.read("<video0>", fps=20)
 
-    import visvis as vv
+    import visvis as vv  # type: ignore
 
     im = reader.get_next_data()
     f = vv.clf()
