@@ -29,3 +29,20 @@ def test_exclude_applied(test_images):
         iio.v3.immeta(
             test_images / "chelsea.png", exclude_applied=True, plugin="PNG-PIL"
         )
+
+
+def test_ellipsis_index(test_images):
+    img = iio.v3.imread(test_images / "chelsea.png", plugin="PNG-FI", index=...)
+    assert img.shape == (1, 300, 451, 3)
+
+    props = iio.v3.improps(
+        test_images / "chelsea.png",
+        plugin="PNG-FI",
+        index=...,
+    )
+    assert props.shape == (1, 300, 451, 3)
+
+    metadata = iio.v3.immeta(
+        test_images / "chelsea.png", plugin="PNG-FI", index=0, exclude_applied=False
+    )
+    assert metadata == {}
